@@ -283,6 +283,7 @@ g_io_modules_load_all_in_directory (const char *dirname)
   return modules;
 }
 
+G_LOCK_DEFINE_STATIC (registered_extensions);
 G_LOCK_DEFINE_STATIC (loaded_dirs);
 
 extern GType _g_fen_directory_monitor_get_type (void);
@@ -297,19 +298,17 @@ extern GType g_win32_directory_monitor_get_type (void);
 extern GType _g_winhttp_vfs_get_type (void);
 
 void
-_g_io_modules_ensure_loaded (void)
+_g_io_modules_ensure_extension_points_registered (void)
 {
-  GList *modules, *l;
-  static gboolean loaded_dirs = FALSE;
+  static gboolean registered_extensions = FALSE;
   GIOExtensionPoint *ep;
-  const char *module_path;
 
-  G_LOCK (loaded_dirs);
-
-  if (!loaded_dirs)
+  G_LOCK (registered_extensions);
+  
+  if (!registered_extensions)
     {
-      loaded_dirs = TRUE;
-
+      registered_extensions = TRUE;
+      
 #ifdef G_OS_UNIX
       ep = g_io_extension_point_register (G_DESKTOP_APP_INFO_LOOKUP_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_DESKTOP_APP_INFO_LOOKUP);
@@ -320,7 +319,7 @@ _g_io_modules_ensure_loaded (void)
       
       ep = g_io_extension_point_register (G_LOCAL_FILE_MONITOR_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_LOCAL_FILE_MONITOR);
-
+      
       ep = g_io_extension_point_register (G_VOLUME_MONITOR_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_VOLUME_MONITOR);
       
@@ -329,7 +328,29 @@ _g_io_modules_ensure_loaded (void)
       
       ep = g_io_extension_point_register (G_VFS_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_VFS);
-      
+
+      ep = g_io_extension_point_register ("gsettings-backend");
+      g_io_extension_point_set_required_type (ep, G_TYPE_OBJECT);
+    }
+  
+  G_UNLOCK (registered_extensions);
+ }
+
+void
+_g_io_modules_ensure_loaded (void)
+{
+  GList *modules, *l;
+  static gboolean loaded_dirs = FALSE;
+  const char *module_path;
+
+  _g_io_modules_ensure_extension_points_registered ();
+  
+  G_LOCK (loaded_dirs);
+
+  if (!loaded_dirs)
+    {
+      loaded_dirs = TRUE;
+
       modules = g_io_modules_load_all_in_directory (GIO_MODULE_DIR);
 
       module_path = g_getenv ("GIO_EXTRA_MODULES");
@@ -593,7 +614,7 @@ g_io_extension_point_implement (const char *extension_point_name,
       return NULL;
     }      
 
-  /* Its safe to register the same type multiple times */
+  /* It's safe to register the same type multiple times */
   for (l = extension_point->extensions; l != NULL; l = l->next)
     {
       extension = l->data;
